import {select,
        csv,
        scaleLinear,
        max,
        scalePoint,
        axisLeft,
        axisBottom
       } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top: 50, right: 40, bottom: 70, left: 200};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice();
    
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.7);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight);
  	//.tickFormat(format('.2s'));
  	
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  
  g.append('g')
    .call(yAxis)
  	.select('.domain')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
      .attr('transform',`translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  	
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('y', 60)
  	.attr('x', innerWidth/2)
		.text('Population');
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
    	.attr('cx', d => xScale(xValue(d)))
  		.attr('r', 20);
  g.append('text')
  .attr('class', 'title')
  	.attr('y', -10)
  	.text('Top 10 most populates countries')
};


csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population;
  });
  render(data);
});